@@ -691,7 +691,7 @@ sub end_item
     $_ = pop_output;
     my $_output_item = "_output_" . $list_type . "_item";
     &{$Format."::".$_output_item}( $_, \@tag, $enum_type ) if length( $_ );
-    $item_counter++;
+    $item_counter++ if $list_type eq 'enumlist';
     @tag = ();
 }
 
